@@ -3,7 +3,7 @@ import cv2
 import pdf2image
 import numpy as np
 
-from .engine import get_instruments_dict, predict_parts_in_imgs, generateImagesFromPdf
+from .engine import get_instruments_dict, predict_parts_in_imgs, generateImagesFromPdf, predict_part_from_string as engine_predict_part_from_string
 from .pdf_predictor import PdfPredictor
 
 from .engine import predict_parts_in_img
@@ -79,3 +79,10 @@ def processUploadedPdf(pdfPath, imagesDirPath, instruments_file=None, instrument
 
 	return predict_parts_in_imgs(imgs, instruments, use_lstm=use_lstm, tessdata_dir=tessdata_dir)
 
+
+def predict_part_from_string(string, instruments_file=None, instruments=None):
+	instruments = get_instruments_dict(
+		instruments=instruments,
+		instruments_file=instruments_file,
+	)
+	return engine_predict_part_from_string(string, instruments)
